@@ -141,7 +141,7 @@ class WebFeatureService_1_1_0(WebFeatureService_):
         """
         Helper method to make sure the StringIO being returned will work.
 
-        Differences between Python 2.6/2.7/3.x mean we have a lot of cases to handle.
+        Differences between Python 2.7/3.x mean we have a lot of cases to handle.
         """
         if PY2:
             return StringIO(strval)
@@ -151,7 +151,7 @@ class WebFeatureService_1_1_0(WebFeatureService_):
     def getfeature(self, typename=None, filter=None, bbox=None, featureid=None,
                    featureversion=None, propertyname='*', maxfeatures=None,
                    srsname=None, outputFormat=None, method='Get',
-                   startindex=None):
+                   startindex=None, sortby=None):
         """Request and return feature data as a file-like object.
 
         Parameters
@@ -178,6 +178,10 @@ class WebFeatureService_1_1_0(WebFeatureService_):
             Requested response format of the request.
         startindex: int (optional)
             Start position to return feature set (paging in combination with maxfeatures)
+        sortby: list (optional)
+            List of property names whose values should be used to order
+            (upon presentation) the set of feature instances that
+            satify the query.
 
         There are 3 different modes of use
 
@@ -228,6 +232,11 @@ class WebFeatureService_1_1_0(WebFeatureService_):
                 propertyname = [propertyname]
             request['propertyname'] = ','.join(propertyname)
 
+        if sortby is not None:
+            if not isinstance(sortby, list):
+                sortby = [sortby]
+            request['sortby'] = ','.join(sortby)
+
         if featureversion is not None:
             request['featureversion'] = str(featureversion)
         if maxfeatures is not None:
@@ -299,10 +308,13 @@ class ContentMetadata:
         self.boundingBoxWGS84 = None
         b = BoundingBox(elem.find(nspath_eval('ows:WGS84BoundingBox', namespaces)), namespaces['ows'])
         if b is not None:
-            self.boundingBoxWGS84 = (
-                    float(b.minx), float(b.miny),
-                    float(b.maxx), float(b.maxy),
-                    )
+            try:
+                self.boundingBoxWGS84 = (
+                        float(b.minx), float(b.miny),
+                        float(b.maxx), float(b.maxy),
+                        )
+            except TypeError:
+                self.boundingBoxWGS84 = None
         # crs options
         self.crsOptions = [Crs(srs.text) for srs in elem.findall(nspath_eval('wfs:OtherSRS', namespaces))]
         dsrs = testXMLValue(elem.find(nspath_eval('wfs:DefaultSRS', namespaces)))
